==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE55S.sql <==
/****************************************************************************/
/* GE55 ( 出力先ﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GE55 (
   SYSTEM_ID        VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , PRTID            VARCHAR (  20 )                 NOT NULL            /*  20 ﾌﾟﾘﾝﾀID      */
 , PRTNM            VARCHAR ( 100 )                                     /*  30 ﾌﾟﾘﾝﾀ名      */
 , PORTNM           VARCHAR (  30 )                                     /*  40 ﾎﾟｰﾄ名       */
 , COMMENTS         TEXT                                                /*  50 ｺﾒﾝﾄ         */
 , RELEASE_NOTES    VARCHAR ( 120 )                                     /*  60 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR (  20 )                                     /*  70 設変番号     */
 , PRT_GRP          VARCHAR (  20 )                                     /*  80 ﾌﾟﾘﾝﾀｰｸﾞﾙｰﾌﾟ */
 , HOST_ID          VARCHAR (  50 )                                     /* 150 ﾎｽﾄ          */
 , FGJ              VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR (  14 )                                     /* 820 登録日時     */
 , PGSET            VARCHAR (  10 )                                     /* 830 作成PG       */
 , PGPSET           VARCHAR (  10 )                                     /* 840 作成親PG     */
 , USRSET           VARCHAR (  10 )                                     /* 850 作成者       */
 , DYUPD            VARCHAR (  14 )                                     /* 860 更新日時     */
 , PGUPD            VARCHAR (  10 )                                     /* 870 更新PG       */
 , PGPUPD           VARCHAR (  10 )                                     /* 880 更新親PG     */
 , USRUPD           VARCHAR (  10 )                                     /* 890 更新者       */
);

==> openGion7.3.0.1_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GE55S.sql <==
/****************************************************************************/
/* GE55 ( 出力先ﾏｽﾀ )                                                       */
/*                                                                          */
/* Created : 2020/12/16 08:14:03                                            */
/****************************************************************************/

CREATE TABLE GE55 (
   SYSTEM_ID        VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID       */
 , PRTID            VARCHAR (  20 )                 NOT NULL            /*  20 ﾌﾟﾘﾝﾀID      */
 , PRTNM            VARCHAR ( 100 )                                     /*  30 ﾌﾟﾘﾝﾀ名      */
 , PORTNM           VARCHAR (  30 )                                     /*  40 ﾎﾟｰﾄ名       */
 , COMMENTS         TEXT                                                /*  50 ｺﾒﾝﾄ         */
 , RELEASE_NOTES    VARCHAR ( 120 )                                     /*  60 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR (  20 )                                     /*  70 設変番号     */
 , PRT_GRP          VARCHAR (  20 )                                     /*  80 ﾌﾟﾘﾝﾀｰｸﾞﾙｰﾌﾟ */
 , HOST_ID          VARCHAR (  50 )                                     /* 150 ﾎｽﾄ          */
 , FGJ              VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR (  14 )                                     /* 820 作成日時     */
 , PGSET            VARCHAR (  10 )                                     /* 830 作成PG       */
 , PGPSET           VARCHAR (  10 )                                     /* 840 作成親PG     */
 , USRSET           VARCHAR (  10 )                                     /* 850 作成者       */
 , DYUPD            VARCHAR (  14 )                                     /* 860 更新日時     */
 , PGUPD            VARCHAR (  10 )                                     /* 870 更新PG       */
 , PGPUPD           VARCHAR (  10 )                                     /* 880 更新親PG     */
 , USRUPD           VARCHAR (  10 )                                     /* 890 更新者       */
);
